# -*- coding: utf-8 -*-
################################################################
# imports
#
from __future__ import print_function
from setuptools import setup
import os.path
import platform
import sys

if (sys.version_info[:2] < (2, 7)) or ((3, 0) <= sys.version_info[:2] < (3, 5)) \
   or sys.version_info[:2] > (3, 6):
    raise RuntimeError("Python version 2.7 or (>= 3.5 and <= 3.6) required.")

osname = platform.system()

try:
# Force a non-pure Python build to wheel: https://stackoverflow.com/a/45150383
    from wheel.bdist_wheel import bdist_wheel as _bdist_wheel
    class bdist_wheel(_bdist_wheel):
        def finalize_options(self):
            _bdist_wheel.finalize_options(self)
            self.root_is_pure = False
        # If we need to modify the Python and/or Python ABI version in the name, see:
        # https://github.com/Yelp/dumb-init/blob/48db0c0d0ecb4598d1a6400710445b85d67616bf/setup.py#L11-L27
        def get_tag(self):
           python, abi, plat = _bdist_wheel.get_tag(self)
           if osname == "Linux":  # Don't modify on Darwin.
               # Pypi only supports upload of wheels with "manylinux" tag.
               # Here we trick it! We're not truely manylinux.
               plat = 'manylinux1_x86_64'
           return python, abi, plat
except ImportError:
    bdist_wheel = None

################################################################
# version checks
#
if sys.maxunicode == 1114111:
    ucs = 'ucs4'
else:
    ucs = 'ucs2'
pyver = sys.version[0:3]
arch  = platform.architecture()[0]

if pyver != '2.7' or ucs != 'ucs2'  or arch != '64bit':
    print("You are using Python " + arch + " " + pyver + " with Unicode " + ucs + ".")
    print("But this ziPython requires Python 64bit 2.7 with Unicode ucs2.")
    print("Installation exits.")
    print("")
    print("Please download another version that corresponds to your Python system.")
    print("")
    sys.exit(1)

################################################################
# OS dependent settings
#

library_dirs = ['../']
if osname == "Windows":
    libraries = ['ziPython.pyd']
    requires = ['numpy']
    if pyver == '2.7':
        requires = ['numpy>=1.6']
    elif pyver == '3.5':
        requires = ['numpy>=1.10']
    elif pyver == '3.6':
        requires = ['numpy>=1.12']
    elif pyver == '3.7':
        requires = ['numpy>=1.14']
elif osname == "Linux":
    libraries = ['ziPython.so']
    if pyver == '2.7':
        requires = ['numpy>=1.6']
    elif pyver in ['3.5', '3.6']:
        requires = ['numpy>=1.7']
    elif pyver == '3.7':
        requires = ['numpy>=1.14']
elif  osname == "Darwin":
    libraries = ['ziPython.so']
    requires = ['numpy>=1.13']
else:
    print("The OS '" + osname + "' is not supported. Exit.")
    sys.exit(1)


################################################################
# pypi classifiers
#
classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Natural Language :: English',
    'Operating System :: Microsoft :: Windows',
    'Operating System :: POSIX :: Linux',
    'Operating System :: MacOS :: MacOS X',
    'Programming Language :: C++',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Topic :: Scientific/Engineering',
    'Topic :: Software Development :: Libraries :: Python Modules',
    ]


################################################################
# long description from README
#
this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md')) as f:
    long_description = f.read()


################################################################
# main section
#
setup(name='zhinst',
      version='18.05.54618',
      description='Python API for Zurich Instruments Devices',
      long_description=long_description,
      long_description_content_type='text/markdown',
      author='Zurich Instruments AG',
      author_email='info@zhinst.com',
      url='http://www.zhinst.com',
      platforms=["windows", "Linux", "Darwin"],
      requires_python='=2.7.*, =3.5.*, =3.6.*',
      cmdclass={'bdist_wheel': bdist_wheel},
      install_requires=requires,
      classifiers=classifiers,
      include_dirs=library_dirs,
      packages=['zhinst',
                'zhinst.examples',
                'zhinst.examples.common',
                'zhinst.examples.deprecated',
                'zhinst.examples.hf2',
                'zhinst.examples.uhf',
                'zhinst.examples.hdawg'],
      package_dir={'zhinst': 'zhinst'},
      package_data={'zhinst': libraries},
      )

